<?php
if(!defined('ABS_PATH')) {
  define('ABS_PATH', dirname(dirname(dirname(__FILE__))) . '/');
}


osc_reset_preferences();


// GET PARAMETERS OF PLUGIN (starting with zc_ only)
function zc_get_params() {
  $zc_params = array();
  $params = Params::getParamsAsArray();

  $list = array();
  foreach(array_keys($params) as $p) {
    if (strpos($p, 'zc_') !== false) {
      $zc_params[$p] = $params[$p];
    }
  }

  return $zc_params;
}



// CHECK IF CONFIGURATOR PARAMETER WAS SAVED (if menu should be shown)
function zc_check_params() {
  $is = false;
  $params = Params::getParamsAsArray();

  $list = array();
  foreach(array_keys($params) as $p) {
    if (strpos($p, 'zc') !== false) {
      $is = true;
      break;
    }
  }

  return $is;
}



// SAVE PARAMETERS TO COOKIES (if oc-admin not logged in)
function zc_params_to_cookies() {
  $params = Params::getParamsAsArray();

  $list = array();
  foreach(array_keys($params) as $p) {
    if (strpos($p, 'zc_') !== false) {
      mb_set_cookie($p, $params[$p]);
    }
  }
}



// SAVE PARAMETERS (not to cookies)
function zc_params_save() {
  $zc_params = array();
  $params = Params::getParamsAsArray();

  $list = array();
  foreach(array_keys($params) as $p) {
    if (strpos($p, 'zc_') !== false) {
      osc_set_preference($p, $params[$p], 'zara_configurator');
    }
  }

  // Banners
  $banner_id = Params::getParam('zcb_banner_id');

  if($banner_id <> '') {
    $banner_group_id = Params::getParam('zcb_banner_group_id');
    $banner_code = Params::getParam('zcb_banner_code', false, false);
    $banner_array =  $banner_group_id . ';-;-;' . $banner_code;

    osc_set_preference($banner_id, $banner_array, 'zara_configurator');
  }
}



// LIST OF EXISTING BANNERS
function zc_banner_define() {
  $zc_banner_define = array(
    array('id' => '', 'name' => '--'),

    array('id' => 'home1', 'name' => __('Home #1 (top)', 'zara_configurator')),
    array('id' => 'home2', 'name' => __('Home #2 (video)', 'zara_configurator')),
    array('id' => 'home3', 'name' => __('Home #3 (map)', 'zara_configurator')),
    array('id' => 'home4', 'name' => __('Home #4 (slider)', 'zara_configurator')),
    array('id' => 'home5', 'name' => __('Home #5 (premiums)', 'zara_configurator')),
    array('id' => 'home6', 'name' => __('Home #6 (latest)', 'zara_configurator')),

    array('id' => '', 'name' => '--'),

    array('id' => 'item1', 'name' => __('Item #1 (top)', 'zara_configurator')),
    array('id' => 'item2', 'name' => __('Item #2 (images)', 'zara_configurator')),
    array('id' => 'item3', 'name' => __('Item #3 (details)', 'zara_configurator')),
    array('id' => 'item4', 'name' => __('Item #4 (description)', 'zara_configurator')),
    array('id' => 'item5', 'name' => __('Item #5 (comments)', 'zara_configurator')),
    array('id' => 'item6', 'name' => __('Item #6 (related ads)', 'zara_configurator')),
    array('id' => 'item7', 'name' => __('Item #7 (sidebar - user info)', 'zara_configurator')),
    array('id' => 'item8', 'name' => __('Item #8 (sidebar - bottom)', 'zara_configurator')),

    array('id' => '', 'name' => '--'),

    array('id' => 'search1', 'name' => __('Search #1 (top)', 'zara_configurator')),
    array('id' => 'search2', 'name' => __('Search #2 (sidebar bottom)', 'zara_configurator')),
    array('id' => 'search3', 'name' => __('Search #3 (list - 2nd position)', 'zara_configurator')),
    array('id' => 'search4', 'name' => __('Search #4 (list - 6th position', 'zara_configurator')),
    array('id' => 'search5', 'name' => __('Search #5 (grid - 2nd position)', 'zara_configurator')),
    array('id' => 'search6', 'name' => __('Search #6 (grid - 9th position)', 'zara_configurator')),
    array('id' => 'search7', 'name' => __('Search #7 (grid - 13th position)', 'zara_configurator')),

    array('id' => '', 'name' => '--'),

    array('id' => 'public1', 'name' => __('Public Profile #1 (contact button)', 'zara_configurator'))
  );

  return $zc_banner_define;
}



// ADD VARIABLES CONTAINING BANNER INFORMATION INTO FOOTER
function zc_banner_js() {
  osc_reset_preferences();
  $banner_list = zc_banner_define();

  $html  = '<script type="text/javascript">' . PHP_EOL;
  $html .= "var banner_ = ['', '']; " . PHP_EOL;

  foreach( $banner_list as $b ) {
    if( $b['id'] <> '' ) {
      $info = osc_get_preference($b['id'], 'zara_configurator');
      $info = explode(';-;-;', $info);


      // To make sure javascript code will be escaped, first code is encoded to rawurl using php function rawurlencod
      // Then, it is converted back using javascript function decodeURIComponent
      if($info[1] <> '') {
        $code = $info[1];
        $code = rawurlencode( $code );
      } else {
        $code = '';
      }
      
      $html .= "var banner_" . $b['id'] . " = ['" . $info[0] . "', '" . $code . "']; " . PHP_EOL;
    }
  }

  $html .= '</script>';
  echo $html;
}



// GET LIST OF BANNER GROUPS, IF ADVERTISEMENT MANAGER PLUGIN IS INSTALLED
function zc_banner_groups(){
  if(function_exists('show_banner')) {
    $groups = ModelAds::newInstance()->getAllBannerGroups();

    if( count($groups) <= 0 ) {
      return array();
    } else {
      return $groups;
    }
  }
}



// DROP ALL PARAMETERS FROM COOKIES & PARAMS
function zc_params_drop() {
  $params = Params::getParamsAsArray();

  $list = array();
  foreach(array_keys($params) as $p) {
    if (strpos($p, 'zc_') !== false) {
      Params::setParam($p, "");
      mb_set_cookie($p, "");
    }
  }
}



// SHOW CONFIGURATION FORM IN FRONT-OFFICE
function zc_config_form() {
  if(osc_is_admin_user_logged_in() or (function_exists('zara_is_demo') && zara_is_demo())) {
    include 'form/configure.php';
  }
}



// SHOW HOMEPAGE MAP
function zc_home_map() {
  if(function_exists('radius_map_items')) { 
    radius_map_items(); 
  } else {
    return false;
  }
}



// SHOW BANNER INSIDE THEME
function zc_banner( $location, $id ) {
  osc_reset_preferences();
  $highlight = zc_current('zc_banner_highlight'); 
  $banner_info = osc_get_preference($location . $id, 'zara_configurator');
  $banner_info = explode(';-;-;', $banner_info);

  $html  = '<div class="zc-banner ' . (osc_is_admin_user_logged_in() ? ($highlight == 1 ? 'visible' : '') : '') . '" data-banner-id="' . $id . '" data-banner-location="' . $location . '" data-banner-code="' . $location . $id . '">';

  if(osc_is_admin_user_logged_in() && $highlight == 1) {
    $html .= '<div class="zc-banner-edit"><span class="first"><i class="fa fa-pencil"></i> <div class="alt1">' . __('Click to edit banner', 'zara_configurator'). '</div><div class="alt2">' . __('Edit', 'zara_configurator') . '</div> <span>#' . $location . $id . '</span></span><span class="second"' . __('This block is visible only if you are loogged in to oc-admin in same browser', 'zara_configurator') . '</span></div>';
  }


  $html .= '<div class="zc-banner-body">';

  if( $banner_info['0'] == '' && $banner_info['1'] == '' && osc_is_admin_user_logged_in() && $highlight == 1 ) {

    // Banner is empty
    $html .= '<span class="is_empty">' . __('This banner does not contain any code and is not related to any banner group', 'zara_configurator') . '</span>';
  } else if ( $banner_info['0'] <> '' && function_exists('show_banner') ) {

    // Association with banner group (Advertisement Manager)
    $html .= show_banner(intval($banner_info['0']));
  } else {

    // Banner code
    $html .= rawurldecode($banner_info['1']);
  }

  $html .= '</div>';
  $html .= '</div>';

  // HACK TO RELOAD PAGE WHEN POSTED CODE IS SAME AS SHOWN ON SAME PAGE (otherwise chrome error)
  if(!empty($_POST['zcb_banner_code']) && strpos($_POST['zcb_banner_code'], 'script')) { 
    //echo "<script>document.location=document.location;</script>";
    header('Location: ' . $_SERVER['REQUEST_URI']);
  }

  return $html;
}



// GET CODE OF BANNER (IT'S CONTENT)
function zc_banner_code( $location, $id ) {
  $banner_info = osc_get_preference($location . $id, 'zara_configurator');
  $banner_info = explode(';-;-;', $banner_info);

  return trim($banner_info['1']);
}



// ADD STYLES RELATED TO CURRENT COLOR & FONT
function zc_enqueue_styles(){
  if(zc_current('zc_font') <> '' && zc_current('zc_font') <> 'font-default') {
    osc_enqueue_style('zara-font', osc_base_url() . 'oc-content/plugins/zara_configurator/css/font/' . zc_current('zc_font') . '.css');
  }

  if(zc_current('zc_color') <> '' && zc_current('zc_color') <> 'theme-default') {
    osc_enqueue_style('zara-color', osc_base_url() . 'oc-content/plugins/zara_configurator/css/color/' . zc_current('zc_color') . '.css');
  }
}



// GET CURRENT PARAMETER (consider cookies, params, preference, admin)
function zc_current( $name, $default = '' ) {
  if(Params::getParam($name) <> '') {
    return Params::getParam($name);
  } else if (mb_get_cookie($name) <> '' && !osc_is_admin_user_logged_in()) {
    return mb_get_cookie($name);
  } else if( osc_get_preference($name, 'zara_configurator') <> '' ) {
    return osc_get_preference($name, 'zara_configurator');
  } else {
    $default;
  }  
}



// COOKIES MANAGEMENT
if(!function_exists('mb_set_cookie')) {
  function mb_set_cookie($name, $val) {
    Cookie::newInstance()->set_expires( 86400 * 30 );
    Cookie::newInstance()->push($name, $val);
    Cookie::newInstance()->set();
  }
}

if(!function_exists('mb_get_cookie')) {
  function mb_get_cookie($name) {
    return Cookie::newInstance()->get_value($name);
  }
}


if(!function_exists('mb_drop_cookie')) {
  function mb_drop_cookie($name) {
    Cookie::newInstance()->pop($name);
  }
}


if(!function_exists('mb_drop_cookies')) {
  function mb_drop_cookies() {
    Cookie::newInstance()->clear();
  }
}

?>